@@ -7,7 +7,7 @@ import os
 import shutil
 
 def create_suource_can_loop_path(clip_path, is_delete = True, ext="mp4"):
-    return create_source_can_loop(get_dir('download'), clip_path, is_delete = is_delete, ext=ext)
+    return create_source_can_loop(get_dir('download'), clip_path, is_delete = is_delete, ext="mp4")
 def create_source_can_loop(dir_path, clip_path, is_delete = True, ext = "mp4" ):
     tmp_clip_path_z_resync = None
     try:
